function vexpower_loaddefaults(force)
	local newChar, newAccount = vexpower_CheckForNewData()
	local defaultProfileLoaded = vexpower_LoadDefaultProfile()
	
	local PowerShowWithMana, CPsShowWithMana, CPsShowWithoutEnergy, infightshow, infightshowCP, vehiclehide, stealthshow, stealthshowCP = vexpower_GetOldData()
	
	if newChar and not(defaultProfileLoaded) then
		vexpower_defaults["frame"]["energy"]["text"] = vexpower_CopyTable(vexpower_text_defaults)
	end
	
	vexpower_default_data =  vexpower_check_tablecontent(vexpower_default_data_default, vexpower_default_data, force)
	vexpower_loadClassPreset(newChar, newAccount)
	vexpower_parameters =  vexpower_check_tablecontent(vexpower_defaults, vexpower_parameters, force)
	
	vexpower_checkOldVariables6()
	vexpower_checkOldVariables7(PowerShowWithMana, CPsShowWithMana, CPsShowWithoutEnergy)
	vexpower_checkOldVariables8(infightshow, infightshowCP, vehiclehide, stealthshow, stealthshowCP)
	vexpower_checkOldVariables10()
	vexpower_checkOldVariables11()
	
	if vexpower_profiles == nil then vexpower_profiles = { } end
	
	vexpower_cleanParameters()
	
	if force then vexpower_initialize(true) end
end

function vexpower_check_tablecontent(defaults, saved, force, noadding)
	local temp = {}
	if force or type(saved) ~= "table" then temp=defaults
	else
		for key,val in pairs(defaults) do
			if type(val) == "table" then
				temp[key] = {}
				if saved[key] == nil then
					temp[key] = val
				else
					temp[key] = vexpower_check_tablecontent(defaults[key], saved[key], force, noadding)
				end
			else
				if saved[key] == nil then
					temp[key] = val
				else
					temp[key] = saved[key]
				end
			end
		end
		
		--adds information that is not in the defaults list --> 'markers'
		if not(noadding) then
			for key,val in pairs(saved) do
				if type(val) == "table" then
					temp[key] = {}
					if defaults[key] == nil then
						temp[key] = val
					else
						temp[key] = vexpower_check_tablecontent(defaults[key], saved[key], force, noadding)
					end
				else
					if defaults[key] == nil then
						temp[key] = val
					else
						temp[key] = saved[key]
					end
				end
			end
		end
	end
	return temp
end

function vexpower_CheckForNewData()
	local newChar = false
	local newAccount = false
	
	if vexpower_parameters == nil and vexpower_profiles == nil and vexpower_default_data == nil then
		newAccount = true
	end
	if vexpower_parameters == nil then
		newChar = true
	end
	return newChar, newAccount
end

function vexpower_LoadDefaultProfile()
	local defaultProfileLoaded = false
	if vexpower_parameters == nil and vexpower_profiles ~= nil and vexpower_default_data ~= nil then
		if vexpower_default_data["activate"] then
			if vexpower_profiles[vexpower_default_data["profile"]] ~= nil then
				vexpower_profiles_profile_load = vexpower_default_data["profile"]
				vexpower_profile_load()
				defaultProfileLoaded = true
			else
				print("|CFFFF7D0AVex Power|r ERROR: Could not load default profile. Default profile '"..vexpower_default_data["profile"].."' doesn't exist.")
				print("|CFFFF7D0AVex Power|r ERROR: Default addon settings will loaded instead. You can still load another profile manually in the options")
			end
		end
	end
	return defaultProfileLoaded
end

function vexpower_cleanParameters()
	local markers = vexpower_CopyTable(vexpower_parameters["frame"]["energy"]["markers"]["points"])
	local markers_a = vexpower_CopyTable(vexpower_parameters["frame"]["energy"]["markers"]["points_spec_a"])
	local markers_b = vexpower_CopyTable(vexpower_parameters["frame"]["energy"]["markers"]["points_spec_b"])
	local textfields = vexpower_CopyTable(vexpower_parameters["frame"]["energy"]["text"])
	local colorpresets = vexpower_CopyTable(vexpower_default_data["colorpresets"])
	
	vexpower_parameters =  vexpower_check_tablecontent(vexpower_defaults, vexpower_parameters, force, true)
	vexpower_default_data =  vexpower_check_tablecontent(vexpower_default_data_default, vexpower_default_data, force, true)
	for key,val in pairs(markers) do
		vexpower_parameters["frame"]["energy"]["markers"]["points"][key] = vexpower_check_tablecontent(vexpower_default_marker, val, force, true)
	end
	for key,val in pairs(markers_a) do
		vexpower_parameters["frame"]["energy"]["markers"]["points_spec_a"][key] = vexpower_check_tablecontent(vexpower_default_marker, val, force, true)
	end
	for key,val in pairs(markers_b) do
		vexpower_parameters["frame"]["energy"]["markers"]["points_spec_b"][key] = vexpower_check_tablecontent(vexpower_default_marker, val, force, true)
	end
	
	for key,val in pairs(textfields) do
		vexpower_parameters["frame"]["energy"]["text"][key] =  vexpower_check_tablecontent(vexpower_default_textfield, val, force, true)
	end	
	
	for key,val in pairs(colorpresets) do
		vexpower_default_data["colorpresets"][key] =  vexpower_check_tablecontent(vexpower_default_colorpreset, val, force, true)
	end	
end

function vexpower_loadClassPreset(newChar, newAccount)
	if newChar then
		local class = vexpower_getClass()
		if vexpower_default_data["classpresets"][class][1] or newAccount then
			local preset = vexpower_default_data["classpresets"][class][2]
			if vexpower_default_data["colorpresets"][preset] ~= nil then
				vexpower_parameters["frame"]["combo"]["bg"]["color"] = vexpower_CopyTable(vexpower_default_data["colorpresets"][preset])
			end
		end
	end
end

function vexpower_GetOldData()
	local PowerShowWithMana = nil
	local CPsShowWithMana = nil
	local CPsShowWithoutEnergy = nil
	
	local infightshow = nil
	local infightshowCP = nil
	local vehiclehide = nil
	local stealthshow = nil
	local stealthshowCP = nil
	
	
	if vexpower_parameters ~= nil then
		if vexpower_parameters["frame"]["energy"]["showwithmana"] ~= nil then
			PowerShowWithMana = vexpower_parameters["frame"]["energy"]["showwithmana"]
			vexpower_parameters["frame"]["energy"]["showwithmana"] = nil
		end
		if vexpower_parameters["frame"]["combo"]["showwithmana"] ~= nil then
			CPsShowWithMana = vexpower_parameters["frame"]["combo"]["showwithmana"]
			vexpower_parameters["frame"]["combo"]["showwithmana"] = nil
		end
		if vexpower_parameters["frame"]["combo"]["showWithoutEnergy"] ~= nil then
			CPsShowWithoutEnergy = vexpower_parameters["frame"]["combo"]["showWithoutEnergy"]
			vexpower_parameters["frame"]["combo"]["showWithoutEnergy"] = nil
		end
		if vexpower_parameters["frame"]["infightshow"] ~= nil then
			infightshow = vexpower_parameters["frame"]["infightshow"]
			vexpower_parameters["frame"]["infightshow"] = nil
		end
		if vexpower_parameters["frame"]["infightshowCP"] ~= nil then
			infightshowCP = vexpower_parameters["frame"]["infightshowCP"]
			vexpower_parameters["frame"]["infightshowCP"] = nil
		end
		if vexpower_parameters["frame"]["vehiclehide"] ~= nil then
			vehiclehide = vexpower_parameters["frame"]["vehiclehide"]
			vexpower_parameters["frame"]["vehiclehide"] = nil
		end
		if vexpower_parameters["frame"]["stealthshow"] ~= nil then
			stealthshow = vexpower_parameters["frame"]["stealthshow"]
			vexpower_parameters["frame"]["stealthshow"] = nil
		end
		if vexpower_parameters["frame"]["stealthshowCP"] ~= nil then
			stealthshowCP = vexpower_parameters["frame"]["stealthshowCP"]
			vexpower_parameters["frame"]["stealthshowCP"] = nil
		end
	end
	return PowerShowWithMana, CPsShowWithMana, CPsShowWithoutEnergy, infightshow, infightshowCP, vehiclehide, stealthshow, stealthshowCP
end